==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/ug.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'ug', {
	button: {
		title: 'توپچا خاسلىقى',
		text: 'بەلگە (قىممەت)',
		type: 'تىپى',
		typeBtn: 'توپچا',
		typeSbm: 'تاپشۇر',
		typeRst: 'ئەسلىگە قايتۇر'
	},
	checkboxAndRadio: {
		checkboxTitle: 'كۆپ تاللاش خاسلىقى',
		radioTitle: 'تاق تاللاش توپچا خاسلىقى',
		value: 'تاللىغان قىممەت',
		selected: 'تاللانغان'
	},
	form: {
		title: 'جەدۋەل خاسلىقى',
		menu: 'جەدۋەل خاسلىقى',
		action: 'مەشغۇلات',
		method: 'ئۇسۇل',
		encoding: 'جەدۋەل كودلىنىشى'
	},
	hidden: {
		title: 'يوشۇرۇن دائىرە خاسلىقى',
		name: 'ئات',
		value: 'دەسلەپكى قىممىتى'
	},
	select: {
		title: 'جەدۋەل/تىزىم خاسلىقى',
		selectInfo: 'ئۇچۇر تاللاڭ',
		opAvail: 'تاللاش تۈرلىرى',
		value: 'قىممەت',
		size: 'ئېگىزلىكى',
		lines: 'قۇر',
		chkMulti: 'كۆپ تاللاشچان',
		opText: 'تاللانما تېكىستى',
		opValue: 'تاللانما قىممىتى',
		btnAdd: 'قوش',
		btnModify: 'ئۆزگەرت',
		btnUp: 'ئۈستىگە',
		btnDown: 'ئاستىغا',
		btnSetValue: 'دەسلەپكى تاللانما قىممىتىگە تەڭشە',
		btnDelete: 'ئۆچۈر'
	},
	textarea: {
		title: ' كۆپ قۇرلۇق تېكىست خاسلىقى',
		cols: 'ھەرپ كەڭلىكى',
		rows: 'قۇر سانى'
	},
	textfield: {
		title: 'تاق قۇرلۇق تېكىست خاسلىقى',
		name: 'ئات',
		value: 'دەسلەپكى قىممىتى',
		charWidth: 'ھەرپ كەڭلىكى',
		maxChars: 'ئەڭ كۆپ ھەرپ سانى',
		type: 'تىپى',
		typeText: 'تېكىست',
		typePass: 'ئىم',
		typeEmail: 'تورخەت',
		typeSearch: 'ئىزدە',
		typeTel: 'تېلېفون نومۇر',
		typeUrl: 'ئادرېس'
	}
} );

==> ckeditor_4.5.6+dfsg.orig.tar.xz: ckeditor-dev-4.5.6/plugins/forms/lang/ug.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'ug', {
	button: {
		title: 'توپچا خاسلىقى',
		text: 'بەلگە (قىممەت)',
		type: 'تىپى',
		typeBtn: 'توپچا',
		typeSbm: 'تاپشۇر',
		typeRst: 'ئەسلىگە قايتۇر'
	},
	checkboxAndRadio: {
		checkboxTitle: 'كۆپ تاللاش خاسلىقى',
		radioTitle: 'تاق تاللاش توپچا خاسلىقى',
		value: 'تاللىغان قىممەت',
		selected: 'تاللانغان',
		required: 'زۆرۈر'
	},
	form: {
		title: 'جەدۋەل خاسلىقى',
		menu: 'جەدۋەل خاسلىقى',
		action: 'مەشغۇلات',
		method: 'ئۇسۇل',
		encoding: 'جەدۋەل كودلىنىشى'
	},
	hidden: {
		title: 'يوشۇرۇن دائىرە خاسلىقى',
		name: 'ئات',
		value: 'دەسلەپكى قىممىتى'
	},
	select: {
		title: 'جەدۋەل/تىزىم خاسلىقى',
		selectInfo: 'ئۇچۇر تاللاڭ',
		opAvail: 'تاللاش تۈرلىرى',
		value: 'قىممەت',
		size: 'ئېگىزلىكى',
		lines: 'قۇر',
		chkMulti: 'كۆپ تاللاشچان',
		required: 'زۆرۈر',
		opText: 'تاللانما تېكىستى',
		opValue: 'تاللانما قىممىتى',
		btnAdd: 'قوش',
		btnModify: 'ئۆزگەرت',
		btnUp: 'ئۈستىگە',
		btnDown: 'ئاستىغا',
		btnSetValue: 'دەسلەپكى تاللانما قىممىتىگە تەڭشە',
		btnDelete: 'ئۆچۈر'
	},
	textarea: {
		title: ' كۆپ قۇرلۇق تېكىست خاسلىقى',
		cols: 'ھەرپ كەڭلىكى',
		rows: 'قۇر سانى'
	},
	textfield: {
		title: 'تاق قۇرلۇق تېكىست خاسلىقى',
		name: 'ئات',
		value: 'دەسلەپكى قىممىتى',
		charWidth: 'ھەرپ كەڭلىكى',
		maxChars: 'ئەڭ كۆپ ھەرپ سانى',
		required: 'زۆرۈر',
		type: 'تىپى',
		typeText: 'تېكىست',
		typePass: 'ئىم',
		typeEmail: 'تورخەت',
		typeSearch: 'ئىزدە',
		typeTel: 'تېلېفون نومۇر',
		typeUrl: 'ئادرېس'
	}
} );
